@@ -26,5 +26,6 @@
 
 import os
 
-def icons(name):
-    return os.path.join(os.path.abspath(os.path.normpath(os.path.dirname(__file__))), u'tango', name)
+
+def icons(name, origin=u"tango"):
+    return os.path.join(os.path.abspath(os.path.normpath(os.path.dirname(__file__))), origin, name)
